@@ -12,6 +12,10 @@ u.sxenv <- function(X, Y, R){
   bic.seq <- -2 * loglik.seq + log(n) * npara.seq
   u.aic <- which.min(aic.seq) - 1
   u.bic <- which.min(bic.seq) - 1
+  if (min(aic.seq) == aic.seq[p+1]) {
+      u.aic = p
+      u.bic = p
+  }
   return(list(u.aic = u.aic, u.bic = u.bic, aic.seq = aic.seq, 
               bic.seq = bic.seq))
 }
\ No newline at end of file
